Index: modules/misc/audioscrobbler.c
===================================================================
--- modules/misc/audioscrobbler.c	(révision 16723)
+++ modules/misc/audioscrobbler.c	(copie de travail)
@@ -4,7 +4,7 @@
  * Copyright (C) 2006 the VideoLAN team
  * $Id$
  *
- * Authors: Rafal Carr <rafael -dot- carre -at- gmail -dot- com>
+ * Authors: Rafaël Carré <rafael -dot- carre -at- gmail -dot- com>
  *          Kenneth Ostby <kenneo -at- idi -dot- ntnu -dot- no>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -250,27 +250,26 @@
  *****************************************************************************/
 static void Close( vlc_object_t *p_this )
 {
+    intf_thread_t               *p_intf;
+    intf_sys_t                  *p_sys;
     audioscrobbler_queue_t      *p_current_queue, *p_next_queue;
+    playlist_t                  *p_playlist;
     input_thread_t              *p_input;
-    intf_thread_t               *p_intf = (intf_thread_t* ) p_this;
-    intf_sys_t                  *p_sys = p_intf->p_sys;
-    playlist_t                  *p_playlist = pl_Yield( p_intf );
 
+    p_intf = ( intf_thread_t* ) p_this;
+    p_sys = p_intf->p_sys;
+
     p_playlist = pl_Yield( p_intf );
-    var_DelCallback( p_playlist, "playlist-current", ItemChange, p_intf );
-
     PL_LOCK;
     p_input = p_playlist->p_input;
-    if( p_input ) vlc_object_yield( p_input );
     PL_UNLOCK;
+    var_DelCallback( p_playlist, "playlist-current", ItemChange, p_intf );
+    pl_Release( p_playlist );
 
-    if( p_input )
-    {
-        var_DelCallback( p_input, "state", PlayingChange, p_intf );
-    }
+    vlc_object_yield( p_input );
+    var_DelCallback( p_input, "state", PlayingChange, p_intf );
+    vlc_object_release( p_input );
 
-    pl_Release( p_playlist );
-
     vlc_mutex_lock ( &p_sys->lock );
     p_current_queue = p_sys->p_first_queue;
     vlc_mutex_unlock ( &p_sys->lock );
@@ -479,6 +478,7 @@
         if( p_playlist->request.i_status == PLAYLIST_STOPPED )
         {
             PL_UNLOCK;
+            pl_Release( p_playlist );
             /* if we stopped, we won't submit playing song */
             vlc_mutex_lock( &p_sys->lock );
             p_sys->b_queued = VLC_TRUE;
@@ -488,9 +488,9 @@
         else
         {
             PL_UNLOCK;
+            pl_Release( p_playlist );
         }
 
-        pl_Release( p_playlist );
         vlc_mutex_lock( &p_sys->lock );
 
         if( p_sys->b_metadata_read == VLC_FALSE )
@@ -611,7 +611,7 @@
     /* reset pause counter */
     p_sys->time_total_pauses = 0;
 
-    /* we save the p_input value to delete the callback later */
+    /* we save the p_input value to delete the callback when we Close() */
     p_sys->p_input = p_input;
 
     /* we'll read after to be sure it's present */
@@ -1030,16 +1030,18 @@
     p_playlist = pl_Yield( p_this );
     PL_LOCK;
     p_input = p_playlist->p_input;
+    PL_UNLOCK;
+    pl_Release( p_playlist );
 
-    if( !p_input )
+    if( p_input)
     {
-        return VLC_SUCCESS;
+	vlc_object_yield( p_input );
     }
+    else
+    {
+        return( VLC_SUCCESS );
+    }
 
-    vlc_object_yield( p_input );
-    PL_UNLOCK;
-    pl_Release( p_playlist );
-
     if ( p_input->input.p_item->i_type == ITEM_TYPE_NET )
     {
         msg_Dbg( p_this, "We play a stream -> no submission");
@@ -1079,8 +1081,7 @@
     }
     else
     {
-        msg_Dbg( p_this, "No album.." );
-        goto no_submission;
+        *psz_album = 0;
     }
 
     if ( p_input->input.p_item->psz_name )
@@ -1121,6 +1122,8 @@
     return VLC_SUCCESS;
 
 error:
+    vlc_object_release( p_input );
+
     free( psz_artist );
     free( psz_album );
     free( psz_title );
